diff imgutils.h @ 18:ebe3b7ce4cca libavcore

Rename av_fill_image_max_pixstep() to av_fill_image_max_pixsteps(). The plural form is preferred as it is more consistent with the other functions: av_fill_image_linesizes() av_fill_image_pointers() and looks semantically more correct as it fills an array of elements.
author stefano
date Fri, 20 Aug 2010 16:52:38 +0000
parents 046c1e516605
children 3b8eec1cfdaa
line wrap: on
line diff
--- a/imgutils.h	Fri Aug 20 16:34:41 2010 +0000
+++ b/imgutils.h	Fri Aug 20 16:52:38 2010 +0000
@@ -36,27 +36,27 @@
  * byte of the successive group in the same plane for the same
  * component.
  *
  * @param max_pixstep an array which is filled with the max pixel step
  * for each plane. Since a plane may contain different pixel
  * components, the computed max_pixstep[plane] is relative to the
  * component in the plane with the max pixel step.
  * @param max_pixstep_comp an array which is filled with the component
  * for each plane which has the max pixel step. May be NULL.
  */
-static inline void av_fill_image_max_pixstep(int max_pixstep[4], int max_pixstep_comp[4],
-                                             const AVPixFmtDescriptor *pixdesc)
+static inline void av_fill_image_max_pixsteps(int max_pixsteps[4], int max_pixstep_comps[4],
+                                              const AVPixFmtDescriptor *pixdesc)
 {
     int i;
-    memset(max_pixstep, 0, 4*sizeof(max_pixstep[0]));
-    if (max_pixstep_comp)
-        memset(max_pixstep_comp, 0, 4*sizeof(max_pixstep_comp[0]));
+    memset(max_pixsteps, 0, 4*sizeof(max_pixsteps[0]));
+    if (max_pixstep_comps)
+        memset(max_pixstep_comps, 0, 4*sizeof(max_pixstep_comps[0]));
 
     for (i = 0; i < 4; i++) {
         const AVComponentDescriptor *comp = &(pixdesc->comp[i]);
-        if ((comp->step_minus1+1) > max_pixstep[comp->plane]) {
-            max_pixstep[comp->plane] = comp->step_minus1+1;
-            if (max_pixstep_comp)
-                max_pixstep_comp[comp->plane] = i;
+        if ((comp->step_minus1+1) > max_pixsteps[comp->plane]) {
+            max_pixsteps[comp->plane] = comp->step_minus1+1;
+            if (max_pixstep_comps)
+                max_pixstep_comps[comp->plane] = i;
         }
     }
 }
@@ -36,27 +36,27 @@
  * component.
  *
- * @param max_pixstep an array which is filled with the max pixel step
+ * @param max_pixsteps an array which is filled with the max pixel step
  * for each plane. Since a plane may contain different pixel
@@ -36,27 +36,27 @@
  * for each plane. Since a plane may contain different pixel
- * components, the computed max_pixstep[plane] is relative to the
+ * components, the computed max_pixsteps[plane] is relative to the
  * component in the plane with the max pixel step.
@@ -36,27 +36,27 @@
  * component in the plane with the max pixel step.
- * @param max_pixstep_comp an array which is filled with the component
+ * @param max_pixstep_comps an array which is filled with the component
  * for each plane which has the max pixel step. May be NULL.
  */